@@ -1,22 +1,32 @@
 /*
     conf.h -- configuration database
-    Copyright (C) 2003-2005 Marc Lehmann <gvpe@schmorp.de>
+    Copyright (C) 2003-2008 Marc Lehmann <gvpe@schmorp.de>
  
     This file is part of GVPE.
 
-    GVPE is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
- 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
- 
-    You should have received a copy of the GNU General Public License
-    along with gvpe; if not, write to the Free Software
-    Foundation, Inc. 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    GVPE is free software; you can redistribute it and/or modify it
+    under the terms of the GNU General Public License as published by the
+    Free Software Foundation; either version 3 of the License, or (at your
+    option) any later version.
+   
+    This program is distributed in the hope that it will be useful, but
+    WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
+    Public License for more details.
+   
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, see <http://www.gnu.org/licenses/>.
+   
+    Additional permission under GNU GPL version 3 section 7
+   
+    If you modify this Program, or any covered work, by linking or
+    combining it with the OpenSSL project's OpenSSL library (or a modified
+    version of that library), containing parts covered by the terms of the
+    OpenSSL or SSLeay licenses, the licensors of this Program grant you
+    additional permission to convey the resulting work.  Corresponding
+    Source for a non-source form of such a combination shall include the
+    source code for the parts of OpenSSL used as well as that of the
+    covered work.
 */
 
 #ifndef GVPE_CONF_H__
@@ -34,6 +44,8 @@
 #define DEFAULT_UDPPORT	       		655	// same as tinc, conflicts would be rare
 #define DEFAULT_MTU	       		1500	// let's ether-net
 #define DEFAULT_MAX_RETRY      		3600	// retry at least this often
+#define DEFAULT_MAX_TTL      		60	// packets expire after this many seconds
+#define DEFAULT_MAX_QUEUE      		512	// never queue more than this many packets
  
 #define DEFAULT_DNS_TIMEOUT_FACTOR	8.F	// initial retry timeout multiple
 #define DEFAULT_DNS_SEND_INTERVAL	.01F	// minimum send interval
@@ -73,6 +85,8 @@ struct conf_node
   u8 protocols;   // protocols this host can send & receive
   u16 udp_port, tcp_port;   // the port to bind to
   int max_retry;
+  double max_ttl;   // packets expire after this many seconds
+  int max_queue;    // maixmum send queue length
 
   enum connectmode { C_ONDEMAND, C_NEVER, C_ALWAYS, C_DISABLED } connectmode;
   bool compress;
@@ -83,7 +97,20 @@ struct conf_node
 
   u32 routerprio;
 
-  bool can_direct (struct conf_node *other);
+  u8 connectable_protocols () const
+  {
+    u8 protocols = this->protocols;
+
+    // mask out endpoints we can't connect to
+    if (!udp_port) protocols &= ~PROT_UDPv4;
+    if (!tcp_port) protocols &= ~PROT_TCPv4;
+    if (!dns_port) protocols &= ~PROT_DNSv4;
+
+    return protocols;
+  }
+
+  bool may_direct (struct conf_node *other);
+  void finalise ();
 
   void print ();
 
